==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebSelectDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebDropdownDescriptionModule } from "./WebDropdownDescriptionModule";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebSelectGroupDescriptionModule } from "./WebSelectGroupDescriptionModule";
import { WebSelectHeaderDescriptionModule } from "./WebSelectHeaderDescriptionModule";
import { WebSelectItemDescriptionModule } from "./WebSelectItemDescriptionModule";
import { WebSelectDescriptionMetadata } from "./WebSelectDescriptionMetadata";
/**
 * @hidden
 */
var WebSelectDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectDescriptionModule, _super);
    function WebSelectDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectDescriptionModule.register = function (a) {
        WebDropdownDescriptionModule.register(a);
        WebIconDescriptionModule.register(a);
        WebInputDescriptionModule.register(a);
        WebSelectGroupDescriptionModule.register(a);
        WebSelectHeaderDescriptionModule.register(a);
        WebSelectItemDescriptionModule.register(a);
        WebSelectDescriptionMetadata.d(a);
    };
    WebSelectDescriptionModule.$t = markType(WebSelectDescriptionModule, 'WebSelectDescriptionModule');
    return WebSelectDescriptionModule;
}(Base));
export { WebSelectDescriptionModule };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebSelectDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebBaseComboBoxLikeDescriptionModule } from "./WebBaseComboBoxLikeDescriptionModule";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebSelectGroupDescriptionModule } from "./WebSelectGroupDescriptionModule";
import { WebSelectHeaderDescriptionModule } from "./WebSelectHeaderDescriptionModule";
import { WebSelectItemDescriptionModule } from "./WebSelectItemDescriptionModule";
import { WebSelectItemComponentEventArgsDescriptionMetadata } from "./WebSelectItemComponentEventArgsDescriptionMetadata";
import { WebSelectDescriptionMetadata } from "./WebSelectDescriptionMetadata";
/**
 * @hidden
 */
var WebSelectDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectDescriptionModule, _super);
    function WebSelectDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectDescriptionModule.register = function (a) {
        WebBaseComboBoxLikeDescriptionModule.register(a);
        WebIconDescriptionModule.register(a);
        WebInputDescriptionModule.register(a);
        WebSelectGroupDescriptionModule.register(a);
        WebSelectHeaderDescriptionModule.register(a);
        WebSelectItemDescriptionModule.register(a);
        WebSelectItemComponentEventArgsDescriptionMetadata.d(a);
        WebSelectDescriptionMetadata.d(a);
    };
    WebSelectDescriptionModule.$t = markType(WebSelectDescriptionModule, 'WebSelectDescriptionModule');
    return WebSelectDescriptionModule;
}(Base));
export { WebSelectDescriptionModule };
